==> igniteui-react-charts-16.6.4.tgz: package/ES2015/PolarSplineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { Type, markType } from "igniteui-react-core/ES2015/type";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Path } from "igniteui-react-core/ES2015/Path";
import { PathGeometry } from "igniteui-react-core/ES2015/PathGeometry";
import { PathFigure } from "igniteui-react-core/ES2015/PathFigure";
import { Extensions } from "igniteui-react-core/ES2015/Extensions";
import { Numeric } from "igniteui-react-core/ES2015/Numeric";
import { Color } from "igniteui-react-core/ES2015/Color";
export class PolarSplineSeries extends PolarLineSeriesBase {
    constructor() {
        super();
        this.ab = PolarSplineSeries.$;
    }
    bf() {
        return new PolarSplineSeriesView(this);
    }
    il(a) {
        super.il(a);
        this.o4 = a;
    }
    ir(a, b, c, d) {
        super.ir(a, b, c, d);
        switch (b) {
            case PolarSplineSeries.$$p[0]:
                this.i4(false);
                break;
        }
    }
    o2(a) {
        let b = a;
        b.c0();
    }
    o3(a, b) {
        this.o2(b);
        let c = b;
        c.c1(a.m, this.o5);
    }
}
PolarSplineSeries.$t = markType(PolarSplineSeries, 'PolarSplineSeries', PolarLineSeriesBase.$);
Type.dep(DependencyProperty, PropertyMetadata, PolarSplineSeries, 'raisePropertyChanged', ['Stiffness:o5:o7', [1, 0.5]]);
export class PolarSplineSeriesView extends PolarLineSeriesBaseView {
    constructor(a) {
        super(a);
        this.cz = null;
        this.c2 = ((() => {
            let $ret = new Path();
            $ret.aj = new PathGeometry();
            return $ret;
        })());
        this.cz = a;
    }
    ap() {
        super.ap();
        let a = new PathGeometry();
        a.b.add(((() => {
            let $ret = new PathFigure();
            return $ret;
        })()));
        this.c2.aj = a;
    }
    c0() {
        Extensions.e(this.c2.aj);
        this.an();
    }
    c1(a, b) {
        this.c2.aj.b = Numeric.h(a.count, (c) => a._inner[c].x, (c) => a._inner[c].y, b);
        this.an();
    }
    a8() {
        super.a8();
        this.c2._stroke = this.e.ku;
        this.c2.ac = this.e.eu;
        this.c2.ai = this.e.k2;
        this.c2.ad = this.e.k3;
    }
    a9() {
        super.a9();
        let a = this.bl();
        this.c2._stroke = a;
        this.c2.ac = this.e.eu + 3;
    }
    a3(a, b) {
        super.a3(a, b);
        a.s(this.c2);
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPathData(a, this.c2, "polarShape", ["Main"]);
    }
    ac() {
        let a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k1 = a;
        this.e.er = 3;
        this.e.es = 1;
        this.e.et = 4;
        this.e.ds = false;
    }
}
PolarSplineSeriesView.$t = markType(PolarSplineSeriesView, 'PolarSplineSeriesView', PolarLineSeriesBaseView.$);

==> igniteui-react-charts-16.6.8.tgz: package/ES2015/PolarSplineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { Type, markType } from "igniteui-react-core/ES2015/type";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Path } from "igniteui-react-core/ES2015/Path";
import { PathGeometry } from "igniteui-react-core/ES2015/PathGeometry";
import { PathFigure } from "igniteui-react-core/ES2015/PathFigure";
import { Extensions } from "igniteui-react-core/ES2015/Extensions";
import { Numeric } from "igniteui-react-core/ES2015/Numeric";
import { Color } from "igniteui-react-core/ES2015/Color";
/**
 * @hidden
 */
export class PolarSplineSeries extends PolarLineSeriesBase {
    constructor() {
        super();
        this.ab = PolarSplineSeries.$;
    }
    bf() {
        return new PolarSplineSeriesView(this);
    }
    im(a) {
        super.im(a);
        this.o6 = a;
    }
    is(a, b, c, d) {
        super.is(a, b, c, d);
        switch (b) {
            case PolarSplineSeries.$$p[0]:
                this.i6(false);
                break;
        }
    }
    o4(a) {
        let b = a;
        b.c0();
    }
    o5(a, b) {
        this.o4(b);
        let c = b;
        c.c1(a.m, this.o7);
    }
}
PolarSplineSeries.$t = markType(PolarSplineSeries, 'PolarSplineSeries', PolarLineSeriesBase.$);
Type.dep(DependencyProperty, PropertyMetadata, PolarSplineSeries, 'raisePropertyChanged', ['Stiffness:o7:o9', [1, 0.5]]);
/**
 * @hidden
 */
export class PolarSplineSeriesView extends PolarLineSeriesBaseView {
    constructor(a) {
        super(a);
        this.cz = null;
        this.c2 = ((() => {
            let $ret = new Path();
            $ret.aj = new PathGeometry();
            return $ret;
        })());
        this.cz = a;
    }
    ap() {
        super.ap();
        let a = new PathGeometry();
        a.b.add(((() => {
            let $ret = new PathFigure();
            return $ret;
        })()));
        this.c2.aj = a;
    }
    c0() {
        Extensions.e(this.c2.aj);
        this.an();
    }
    c1(a, b) {
        this.c2.aj.b = Numeric.h(a.count, (c) => a._inner[c].x, (c) => a._inner[c].y, b);
        this.an();
    }
    a8() {
        super.a8();
        this.c2._stroke = this.e.kw;
        this.c2.ac = this.e.ev;
        this.c2.ai = this.e.k4;
        this.c2.ad = this.e.k5;
    }
    a9() {
        super.a9();
        let a = this.bl();
        this.c2._stroke = a;
        this.c2.ac = this.e.ev + 3;
    }
    a3(a, b) {
        super.a3(a, b);
        a.s(this.c2);
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPathData(a, this.c2, "polarShape", ["Main"]);
    }
    ac() {
        let a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k3 = a;
        this.e.es = 3;
        this.e.et = 1;
        this.e.eu = 4;
        this.e.dt = false;
    }
}
PolarSplineSeriesView.$t = markType(PolarSplineSeriesView, 'PolarSplineSeriesView', PolarLineSeriesBaseView.$);
